=========================================================
``psyclone.psyir.transformations.read_only_verify_trans``
=========================================================

.. automodule:: psyclone.psyir.transformations.read_only_verify_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.read_only_verify_trans


Classes
=======

- :py:class:`ReadOnlyVerifyTrans`:
  This transformation inserts a ReadOnlyVerifyNode or a node derived


.. autoclass:: ReadOnlyVerifyTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ReadOnlyVerifyTrans
      :parts: 1
